convert

Function convert 

pub fn convert(item: &Dinero, rate: &Rate) -> Dinero
Convert a Dinero object from a currency to another.

When using scaled amounts, the function converts the returned object to the safest scale.