Rule

Enum Rule 

pub enum Rule {
Show 110 variants EOI, journal, blank_line, directives, journal_comment, directive, include, glob, price, commodity, commodity_spec, commodity_in_directive, payee_dir, tag_dir, account_dir, commodity_property, payee_property, account_property, tag_property, property_value, alias, note, format, check, assert, isin, iban, country, payee_subdirective, flag, default, transaction_head, automated_transaction_head, transaction, automated_transaction, transaction_date, effective_date, code, status, quote, payee, tag, description, automated_description, comment, comment_content, posting, automated_posting, amount, cost, balance, posting_kind, real, virtual_no_balance, virtual_balance, account, date, time, datetime, date_sep, year, month, day, hour, minute, second, value_expr, expr, or_expr, and_expr, comparison_expr, additive_expr, multiplicative_expr, primary, term, money, currency, regex, string, reserved, unquoted, currency_parts, unquoted_no_number, variable, number, bigint, ws, sep, end, add, mult, and, or, unary, function, comparison, eq, ne, gt, ge, le, lt, decimal_part, decimal_point, number_separator, integer_part, currency_format_positive, currency_format, space, currency_string,
}

Variants



EOI

End-of-input



journal



blank_line



directives



journal_comment



directive



include



glob



price



commodity



commodity_spec



commodity_in_directive



payee_dir



tag_dir



account_dir



commodity_property



payee_property



account_property



tag_property



property_value



alias



note



format



check



assert



isin



iban



country



payee_subdirective



flag



default



transaction_head



automated_transaction_head



transaction



automated_transaction



transaction_date



effective_date



code



status



quote



payee



tag



description



automated_description



comment



comment_content



posting



automated_posting



amount



cost



balance



posting_kind



real



virtual_no_balance



virtual_balance



account



date



time



datetime



date_sep



year



month



day



hour



minute



second



value_expr



expr



or_expr



and_expr



comparison_expr



additive_expr



multiplicative_expr



primary



term



money



currency



regex



string



reserved



unquoted



currency_parts



unquoted_no_number



variable



number



bigint



ws



sep



end



add



mult



and



or



unary



function



comparison



eq



ne



gt



ge



le



lt



decimal_part



decimal_point



number_separator



integer_part



currency_format_positive



currency_format



space



currency_string

Implementations

Source

impl Rule

pub fn all_rules() -> &'static [Rule]